import colorlog
from logging import PercentStyle
from loggerbundle.extra.ExtraKeysResolver import ExtraKeysResolver


class ExtraFieldsFormatter(colorlog.ColoredFormatter):
    def __init__(self, *args, **kwargs):
        self.__orig_fmt = args[0]

        super().__init__(*args, **kwargs)

    def format(self, record):
        extra_keys = ExtraKeysResolver.get_extra_keys(record)

        if not extra_keys:
            return super().format(record)

        def map_placeholder(field_name):
            return "{}: %({})s".format(field_name, field_name)

        extra_keys_placeholders = list(map(map_placeholder, extra_keys))

        self.__set_format(self.__orig_fmt + "\n" + "{" + ", ".join(extra_keys_placeholders) + "}")
        formated = super().format(record)
        self.__set_format(self.__orig_fmt)

        return formated

    def __set_format(self, fmt: str):
        self._fmt = fmt
        self._style = PercentStyle(self._fmt)



from logging import StreamHandler
from loggerbundle.extra.ExtraFieldsFormatter import ExtraFieldsFormatter
from loggerbundle.handler.HandlerFactoryInterface import HandlerFactoryInterface


class StreamHandlerFactory(HandlerFactoryInterface):
    def __init__(
        self,
        format_str: str,
        date_format: str,
    ):
        self.__format_str = format_str
        self.__date_format = date_format

    def create(self):
        cformat = "%(log_color)s" + self.__format_str
        formatter = ExtraFieldsFormatter(cformat, self.__date_format)

        stream_handler = StreamHandler()
        stream_handler.setFormatter(formatter)

        return stream_handler



import unittest
from injecta.testing.services_tester import test_services
from pyfonycore.bootstrap import bootstrapped_container


class LoggerBundleTest(unittest.TestCase):
    def test_init(self):
        container = bootstrapped_container.init("test")
        test_services(container)


if __name__ == "__main__":
    unittest.main()



from logging import getLogger
from typing import List
from loggerbundle.handler.HandlerFactoryInterface import HandlerFactoryInterface


class LoggerFactory:
    def __init__(
        self,
        default_log_level: int,
        handler_factories: List[HandlerFactoryInterface],
    ):
        self.__default_log_level = default_log_level
        self.__handler_factories = handler_factories

    def create(self, logger_name: str, log_level: int = None):
        logger = getLogger(logger_name)
        logger.setLevel(log_level if log_level is not None else self.__default_log_level)

        logger.handlers = list(map(lambda handler_factory: handler_factory.create(), self.__handler_factories))
        logger.propagate = False

        return logger



class ExtraKeysResolver:

    ignored_record_keys = [
        "name",
        "msg",
        "args",
        "created",
        "exc_info",
        "exc_text",
        "filename",
        "func_name",
        "levelname",
        "levelno",
        "lineno",
        "module",
        "msecs",
        "pathname",
        "process",
        "process_name",
        "relative_created",
        "stack_info",
        "thread",
        "thread_name",
    ]

    @staticmethod
    def get_extra_keys(record):
        return record.__dict__.keys() - ExtraKeysResolver.ignored_record_keys



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['loggerbundle',
 'loggerbundle.extra',
 'loggerbundle.handler',
 'loggerbundle.stdout']

package_data = \
{'': ['*'], 'loggerbundle': ['_config/*']}

install_requires = \
['colorlog>=4.0,<5.0', 'pyfony-bundles>=0.4.0b1']

entry_points = \
{'pyfony.bundle': ['create = loggerbundle.LoggerBundle:LoggerBundle']}

setup_kwargs = {
    'name': 'logger-bundle',
    'version': '0.7.0b1',
    'description': 'Logger bundle for the Pyfony framework',
    'long_description': 'Logger bundle for the Pyfony Framework\n',
    'author': 'Jiri Koutny',
    'author_email': 'jiri.koutny@datasentics.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/pyfony/logger-bundle',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
